<?PHP // $Id$ 
      // choice.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004112900)


$string['allowupdate'] = 'Salli monivalinnan pivitys';
$string['answered'] = 'Vastattu';
$string['choice'] = 'Monivalinta $a';
$string['choiceclose'] = 'Saakka';
$string['choicename'] = 'Valinnan nimi';
$string['choiceopen'] = 'Avoinna';
$string['choicetext'] = 'Valinnan teksti';
$string['havetologin'] = 'Sinun pit kirjautua ennen kun voit ottaa osaa monivalintaan ';
$string['modulename'] = 'Monivalinta';
$string['modulenameplural'] = 'Monivalinnat';
$string['mustchooseone'] = 'Sinun pit valita vastaus ennen tallennusta. Tallennusta ei tehty.';
$string['notanswered'] = 'Vastaamatta';
$string['notopenyet'] = 'Pahus, tm aktiviteetti ei ole saativilla ennen kuin $a';
$string['privacy'] = 'Tulosten suojaus';
$string['publish'] = 'Julkaise tulokset';
$string['publishafteranswer'] = 'Nyt tulokset oppilaalle vastaamisen jlkeen';
$string['publishafterclose'] = 'Nyt tulokset oppilaalle kun monivalinta on sulkeutunut';
$string['publishalways'] = 'Nyt tulokset aina oppilaalle';
$string['publishanonymous'] = 'Julkaise tulokset nimettmsti, piilota vastaajien nimet';
$string['publishnames'] = 'Julkaise tulokset, nyt nimet ja vastaukset.';
$string['publishnot'] = 'l julkaise tuloksia';
$string['responses'] = 'Vastaukset';
$string['responsesto'] = 'Vastaukset $a';
$string['savemychoice'] = 'Tallenna valintani';
$string['showunanswered'] = 'Nyt sarake vastaamattomille';
$string['timerestrict'] = 'Rajoita vastaaminen ajanjaksolle';
$string['viewallresponses'] = 'Katsele $a vastausta';

?>
